# -*- coding: utf-8 -*-
from Products.CMFCore import utils, DirectoryView
from Products.Archetypes.atapi import listTypes, process_types
from zope.i18nmessageid import MessageFactory as BaseMessageFactory

import sys, content
from Products.validation import validation
from validator import WidthHeightValidator

validation.register(WidthHeightValidator('isValidDimensions'))

# Module aliases
sys.modules['Products.ATGoogleVideo.ATGoogleVideo'] = content.googlevideo

# Get configuration data, permissions
from config import PROJECTNAME, DEFAULT_ADD_CONTENT_PERMISSION

# Get localization class
MessageFactory = BaseMessageFactory('ATGoogleVideo')

# Register skin directories so they can be added to portal_skins
DirectoryView.registerDirectory('skins', globals())

def initialize(context):

    # Import the type, which results in registerType() being called
    from content import ATGoogleVideo

    contentTypes, constructors, ftis = process_types(listTypes(PROJECTNAME), PROJECTNAME)
 
    utils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = contentTypes,
        permission         = DEFAULT_ADD_CONTENT_PERMISSION,
        extra_constructors = constructors,
        fti                = ftis,
        ).initialize(context)



# -*- coding: utf-8 -*-
from Products.validation.interfaces.IValidator import IValidator
import re

class WidthHeightValidator:
    __implements__ = (IValidator,)

    def __init__(self, name, title=u'width:height validation'):
        self.name = name
        self.title = title

    def __call__(self, value, *args, **kwargs):
        instance    = kwargs.get('instance', None)
        splited = value.split(':')
        # just the format 999+:999+
        if re.compile('([0-9]+)(:[0-9]+)?').match(value) is None:
            return u'Follow this format, please: "width:height"'
        return True



# This Python file uses the following encoding: utf-8

"""
this test suite was based on Martin Aspeli's 'borg' and David Convent's 'DIYPloneStyle' ones

tested on Plone 2.5.5

$Id: base.py 55550 2007-12-13 21:39:06Z hvelarde $
"""

from Products.ATGoogleVideo.config import PROJECTNAME
from Testing import ZopeTestCase

# Let Zope know about the two products we require above-and-beyond a basic
# Plone install (PloneTestCase takes care of these).
ZopeTestCase.installProduct(PROJECTNAME)

# Import PloneTestCase - this registers more products with Zope as a side effect
from Products.PloneTestCase.PloneTestCase import PloneTestCase
from Products.PloneTestCase.PloneTestCase import FunctionalTestCase
from Products.PloneTestCase.PloneTestCase import setupPloneSite

# Set up a Plone site
setupPloneSite(products=[PROJECTNAME])

class ATGoogleVideoTestCase(PloneTestCase):
    """Base class for integration tests for the 'JuliusLite' product. This may
    provide specific set-up and tear-down operations, or provide convenience
    methods.
    """

class ATGoogleVideoFunctionalTestCase(FunctionalTestCase):
    """Base class for functional integration tests for the 'JuliusLite' product. 
    This may provide specific set-up and tear-down operations, or provide 
    convenience methods.
    """



# This Python file uses the following encoding: utf-8

"""
$Id: testSetup.py 55573 2007-12-14 01:51:52Z hvelarde $
"""

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# Import the base test case classes
from base import ATGoogleVideoTestCase

from Products.ATGoogleVideo.config import *

class TestInstallation(ATGoogleVideoTestCase):
    """Ensure product is properly installed"""

    def afterSetUp(self):
        self.catalog    = self.portal.portal_catalog
        self.kupu       = self.portal.kupu_library_tool
        self.skins      = self.portal.portal_skins
        self.types      = self.portal.portal_types
        self.factory    = self.portal.portal_factory
        self.properties = self.portal.portal_properties
        self.metaTypes = ('Google Video',)

    def testSkinLayersInstalled(self):
        self.failUnless('atgooglevideo_images' in self.skins.objectIds())
        self.failUnless('atgooglevideo_templates' in self.skins.objectIds())

    def testTypesInstalled(self):
        for t in self.metaTypes:
            self.failUnless(t in self.types.objectIds())

    def testPortalFactorySetup(self):
        self.failUnless('Google Video' in self.factory.getFactoryTypes())

    def testDefaultPageTypes(self):
        """test that Google Video is an acceptable default-page type"""
        self.failUnless('Google Video' in self.properties.site_properties.getProperty('default_page_types'))

    def testKupuResources(self):
        """test that Google Video is in Kupu's linkable types"""
        linkable = self.kupu.getPortalTypesForResourceType('linkable')
        self.failUnless('Google Video' in linkable)

class TestUninstall(ATGoogleVideoTestCase):
    """ensure product is properly uninstalled"""

    def afterSetUp(self):
        self.kupu = self.portal.kupu_library_tool
        self.properties = self.portal.portal_properties
        self.qitool = self.portal.portal_quickinstaller
        self.qitool.uninstallProducts(products=[PROJECTNAME])

    def testProductUninstalled(self):
        self.failIf(self.qitool.isProductInstalled(PROJECTNAME))

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestInstallation))
    suite.addTest(makeSuite(TestUninstall))
    return suite

if __name__ == '__main__':
    framework()



# This Python file uses the following encoding: utf-8

"""
$Id: googlevideo.py 124560 2010-08-30 14:43:48Z thiromi $
"""

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2005-2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

try:
    from Products.LinguaPlone.public import *
except ImportError:
    # No multilingual support
    from Products.Archetypes.public import *

from zope.interface import implements

from AccessControl import ClassSecurityInfo

from Products.ATContentTypes.content.document import ATCTContent
from Products.ATContentTypes.content.schemata import ATContentTypeSchema
from Products.ATContentTypes.content.schemata import finalizeATCTSchema
from Products.ATContentTypes.lib.historyaware import HistoryAwareMixin
from Products.ATContentTypes.lib.imagetransform import ATCTImageTransform
from Products.CMFCore.permissions import View
from Products.validation import V_REQUIRED

from Products.ATGoogleVideo.config import *
from Products.ATGoogleVideo.interfaces import IATGoogleVideo

ATGoogleVideoSchema = ATContentTypeSchema.copy() + Schema((

    StringField('docId',
        languageIndependent=True,
        required=1,
        #searchable=True,
        widget=StringWidget(
            label='docId',
            label_msgid='label_docId',
            description='Video "docId" identifier.',
            description_msgid='help_docId',
            i18n_domain='ATGoogleVideo',
            size=20,
            ),
        ),

    StringField('quality',
        default='best',
        languageIndependent=True,
        required=1,
        enforceVocabulary=1,
        vocabulary=QUALITY,
        widget=SelectionWidget(
            label='Quality',
            label_msgid='label_quality',
            description='Specifies rendering quality, how graphics are anti-aliased and how bitmaps are smoothed. Use of "best" is recommended.',
            description_msgid='help_quality',
            i18n_domain='ATGoogleVideo',
            ),
        ),

    BooleanField('autoPlay',
        default=1,
        languageIndependent=True,
        required=0,
        widget=BooleanWidget(
            label='autoPlay',
            label_msgid='label_autoPlay',
            description='Specifies whether the movie begins playing immediately on loading in the browser.',
            description_msgid='help_autoPlay',
            i18n_domain='ATGoogleVideo',
            ),
        ),

    ImageField('image',
        languageIndependent=True,
        #max_size=zconf.ATGoogleVideo.max_image_dimension,
        storage=AnnotationStorage(migrate=True),
        sizes={
            'large'   : (768, 768),
            'preview' : (400, 400),
            'mini'    : (200, 200),
            'thumb'   : (128, 128),
            'tile'    :  (64, 64),
            'icon'    :  (32, 32),
            'listing' :  (16, 16),
            },
        validators=(('isNonEmptyFile', V_REQUIRED),),
        widget=ImageWidget(
            label='Image',
            label_msgid='label_image',
            description='Will be shown in the video listing. Image will be scaled to a sensible size.',
            description_msgid='help_image',
            i18n_domain='ATGoogleVideo',
            show_content_type=False,
            ),
        ),

    StringField('dimensions',
        default='425:350',
        required=True,
        validators=('isValidDimensions'),
        widget=StringWidget(
            label='Dimensions',
            label_msgid='label_dimensions',
            description='Video\'s dimensions according to format "width:height". If you give just one value, video\'s dimensions will be a given px square.',
            description_msgid='help_dimensions',
            i18n_domain='ATGoogleVideo',
            size=20,
            ),
        ),

    TextField('transcription',
        languageIndependent=False,
        storage=AnnotationStorage(migrate=True),
        required=False,
        searchable=True,
        default_output_type = 'text/x-html-safe',
        widget=RichWidget(
            label="Transcription",
            label_msgid="label_transcription",
            description="Video's audio transcripted.",
            description_msgid="help_transcription",
            i18n_domain="ATGoogleVideo",
        ),
    ),

    ),)
finalizeATCTSchema(ATGoogleVideoSchema)

class ATGoogleVideo(ATCTContent, HistoryAwareMixin, ATCTImageTransform):
    """An Archetypes based type to store Google Video and YouTube references."""

    implements(IATGoogleVideo)

    security = ClassSecurityInfo()
    
    portal_type = 'Google Video'
    
    schema = ATGoogleVideoSchema
    _at_rename_after_creation = True

    security.declareProtected(View, 'tag')
    def tag(self, **kwargs):
        """Generate image tag using the api of the ImageField
        """
        return self.getField('image').tag(self, **kwargs)

    def __bobo_traverse__(self, REQUEST, name):
        """Transparent access to image scales
        """
        if name.startswith('image'):
            field = self.getField('image')
            image = None
            if name == 'image':
                image = field.getScale(self)
            else:
                scalename = name[len('image_'):]
                if scalename in field.getAvailableSizes(self):
                    image = field.getScale(self, scale=scalename)
            if image is not None and not isinstance(image, basestring):
                # image might be None or '' for empty images
                return image
        
        return ATCTContent.__bobo_traverse__(self, REQUEST, name)
    
    security.declarePublic('View')
    def getRemoteUrl(self):
        '''Returns docId from this object
           This way we don't need to add a new metadata to
           the catalog
        '''
        return self.getDocId()

    security.declarePublic('View')
    def getWidth(self):
        '''Extracts width from field 'dimensions'
        '''
        return self.getDimensions().split(':')[0]

    security.declarePublic('View')
    def getHeight(self):
        '''Extracts height from field 'dimensions'
        '''
        # Retrocompatibility
        dim = self.getDimensions().split(':')
        height = len(dim) > 1 and dim[1] or dim[0]
        return height
        

registerType(ATGoogleVideo, PROJECTNAME)



# This Python file uses the following encoding: utf-8

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2005-2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

from Products.ATContentTypes.interface import IATContentType
from Products.ATContentTypes.interface import IImageContent

class IATGoogleVideo(IATContentType, IImageContent):
    """ marker interface for ATGoogleVideo """



# This Python file uses the following encoding: utf-8

"""
$Id: Install.py 55432 2007-12-13 04:46:09Z hvelarde $
"""

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2005-2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

from StringIO import StringIO

from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.utils import getFSVersionTuple

from Products.ATGoogleVideo.config import PROJECTNAME

def install(self):
    # this code courtesy of Raphael Ritz
    out = StringIO()

    tool=getToolByName(self, "portal_setup")

    if getFSVersionTuple()[:3]>=(3,0,0):
        tool.runAllImportStepsFromProfile(
            "profile-Products.ATGoogleVideo:default",
            purge_old=False)
    else:
        plone_base_profileid = "profile-CMFPlone:plone"
        tool.setImportContext(plone_base_profileid)
        tool.setImportContext("profile-Products.ATGoogleVideo:default")
        tool.runAllImportSteps(purge_old=False)
        tool.setImportContext(plone_base_profileid)

    print >> out, "Successfully installed %s" % PROJECTNAME

    return out.getvalue()



# This Python file uses the following encoding: utf-8

"""
$Id: testContentType.py 124560 2010-08-30 14:43:48Z thiromi $
"""

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# Import the base test case classes
from base import ATGoogleVideoTestCase

#from Interface.Verify import verifyObject
from zope.schema import getValidationErrors
from Products.ATContentTypes.interface import IATContentType
from Products.ATContentTypes.interface import IImageContent
from Products.ATContentTypes.lib.historyaware import HistoryAwareMixin
from Products.ATContentTypes.lib.imagetransform import ATCTImageTransform

from Products.ATGoogleVideo.config import *
from Products.ATGoogleVideo.interfaces import IATGoogleVideo

class TestContentType(ATGoogleVideoTestCase):
    """ ensure content type implementation """

    def afterSetUp(self):
        self.folder.invokeFactory('Google Video', 'video1')
        self.video1 = getattr(self.folder, 'video1')

    def testImplementsATContentType(self):
        iface = IATContentType
        self.assertTrue(iface.providedBy(self.video1))
        self.assertFalse(getValidationErrors(iface, self.video1))

    def testImplementsImageContent(self):
        iface = IImageContent
        self.assertTrue(iface.providedBy(self.video1))
        self.assertFalse(getValidationErrors(iface, self.video1))

    def testImplementsATGoogleVideo(self):
        iface = IATGoogleVideo
        self.assertTrue(iface.providedBy(self.video1))
        self.assertFalse(getValidationErrors(iface, self.video1))

    def testIsHistoryAwareMixin(self):
        self.assertTrue(isinstance(self.video1, HistoryAwareMixin))

    def testIsATCTImageTransform(self):
        self.assertTrue(isinstance(self.video1, ATCTImageTransform))

def isValidGoogleVideoId(id):
    """ Google Video ids are 18 or 19 digits, with or without a minus sign before """
    import re
    p = re.compile('^-?\d{18,19}$')
    return p.match(id) != None

def isValidYouTubeId(id):
    """ YouTube ids are 11 alphanumeric characters, minus signs or underscores """
    import re
    p = re.compile('^[\w-]{11}$')
    return p.match(id) != None

class TestContentCreation(ATGoogleVideoTestCase):
    """ ensure content type can be created and edited """

    def afterSetUp(self):
        self.folder.invokeFactory('Google Video', 'video1')
        self.video1 = getattr(self.folder, 'video1')

    def testCreateGoogleVideo(self):
        self.failUnless('video1' in self.folder.objectIds())

    def testEditGoogleVideo(self):
        self.video1.setTitle('A title')
        self.video1.setDescription('A description')
        self.video1.setDocId('7111080333836653411')
        self.video1.setAutoPlay(True)
        self.video1.setTranscription('<p><b>Simon says:</b> get up, get down</p>')
        self.video1.setDimensions('600:400')
        
        self.assertEqual(self.video1.Title(), 'A title')
        self.assertEqual(self.video1.Description(), 'A description')
        self.assertEqual(self.video1.getDocId(), '7111080333836653411')
        self.assertEqual(self.video1.getAutoPlay(), True)
        self.assertTrue(self.video1.getTranscription().startswith('<p>&lt;p&gt;&lt;b&gt;'), 'Checking if it is escaping HTML tags')
        self.assertEqual(self.video1.getWidth(), '600')
        self.assertEqual(self.video1.getHeight(), '400')

        self.video1.setDimensions('350')
        self.assertEqual(self.video1.getWidth(), '350')
        self.assertEqual(self.video1.getHeight(), '350')

    def testGoogleVideoValidation(self):
        """ this will be used when validation is implemented """
        validGoogleVideo = (
            '7111080333836653411',
            '2373913889068217879',
            '1384277706451157121',
            '-6176702600168718216',
            '-988521890368706730',
            '-6947118853654187245',
            '-6744496180655305393',
            '-9136575504838642038',
            '507732229697832036',
            '-421067427884933323',
        )
        for id in validGoogleVideo:
            self.failUnless(isValidGoogleVideoId(id))

    def testGoogleVideoInvalidation(self):
        """ this will be used when validation is implemented """
        knownWrong = (
            '+6176702600168718216',
            '6A309553DDC2ECB427',
            '-CE622B1BD7578F9916',
            '11108033336653411',
            '50773222969783203',
            'nojWJ6-XmeQ',
            'JahdnOQ9XCA',
            'VcQIwbvGRKU',
            'sMEnn0xJ0l0',
            '9VKlskwm378',
        )
        for id in knownWrong:
            self.failUnless(not isValidGoogleVideoId(id))

    def testYouTubeValidation(self):
        """ this will be used when validation is implemented """
        validYouTube = (
            'nojWJ6-XmeQ',
            'JahdnOQ9XCA',
            'VcQIwbvGRKU',
            'sMEnn0xJ0l0',
            '9VKlskwm378',
            'mdBfbUy-Oz0',
            '_fqbznoeEOI',
            'EpSK0OriE7w',
            '76f2d3AlXxc',
            'QWUh585V2mM',
        )
        for id in validYouTube:
            self.failUnless(isValidYouTubeId(id))

    def testYouTubeInvalidation(self):
        """ this will be used when validation is implemented """
        knownWrong = (
            'nojWJ6-Xme',
            'Jahdn*Q9XCA',
            '-CE622B1BD7578F9916',
            'sMnn0xJ0l0',
            '507732229697',
            '-6947118853654187245',
            '-6744496180655305393',
            '-9136575504838642038',
            '507732229697832036',
            '-421067427884933323',
        )
        for id in knownWrong:
            self.failUnless(not isValidYouTubeId(id))

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestContentType))
    suite.addTest(makeSuite(TestContentCreation))
    return suite

if __name__ == '__main__':
    framework()



from Products.CMFCore.utils import getToolByName

def setupATGoogleVideo(context):

    # to avoid GS run this step again if product has been inspected
    # for an import_steps.xml again.
    if context.readDataFile('atgooglevideo_various.txt') is None:
        return

    portal = context.getSite()

    # Add Google Video to Kupu's linkable types, if Kupu is installed
    kupuTool = getToolByName(portal, 'kupu_library_tool', None)
    if kupuTool != None:
        linkable = list(kupuTool.getPortalTypesForResourceType('linkable'))
        if 'Google Video' not in linkable:
            linkable.append('Google Video')
        kupuTool.updateResourceTypes(({'resource_type' : 'linkable',
                                       'old_type'      : 'linkable',
                                       'portal_types'  :  linkable},))



# BBB for CMF 1.4
try:
    from Products.CMFCore.permissions import setDefaultRoles
except ImportError:
    from Products.CMFCore.CMFCorePermissions import setDefaultRoles

PROJECTNAME = 'ATGoogleVideo'
DEFAULT_ADD_CONTENT_PERMISSION = "Add Google Video"

setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner',))

# Flash video quality
QUALITY = ('low', 'high', 'autolow', 'autohigh', 'best',)



## Script (Python) "getUFOJSCodeFromVideo"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=video_id,quality,auto_play,div_id='video',width='', height=''
##title=
##

""" returns UFO Javascript code """

code = """
    /* <![CDATA[ */
    var FO = { %s };
    UFO.create(FO, '%s');
    /* ]]> */
"""

majorversion = 9
build = 28
params = "movie:'%s', width:'%s', height:'%s', majorversion:'%s', build:'%s', flashvars:'%s', quality:'%s', wmode:'transparent', setcontainercss:'true'"

if video_id[1:].isdigit():
    # is Google Video
    movie = 'http://video.google.com/googleplayer.swf?docId=%s' % video_id
    width_swf = width or 400
    height_swf = height or 326
    flashvars = test(auto_play,'autoplay=true','')

else:
    # is YouTube
    movie = 'http://www.youtube.com/v/%s%s' % (video_id, test(auto_play,'&amp;autoplay=1',''))
    width_swf = width or 425
    height_swf = height or 350
    flashvars = ''

params = params % (movie, width_swf, height_swf, majorversion, build, flashvars, quality)
return code % (params, div_id)



from setuptools import setup, find_packages
import os

version = open(os.path.join("Products", "ATGoogleVideo", "version.txt")).read().strip()

setup(name='Products.ATGoogleVideo',
      version=version,
      description="Use YouTube and Google Video on a Plone Site",
      long_description=open(os.path.join("Products", "ATGoogleVideo", "README.txt")).read().decode('UTF8').encode('ASCII', 'replace') + '\n' +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        ],
      keywords='plone ATGoogleVideo youtube video googlevideo',
      author='Simples Consultoria',
      author_email='products@simplesconsultoria.com.br',
      url='https://svn.plone.org/svn/collective/Products.ATGoogleVideo',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['Products'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



""" returns the latest video """

from Products.CMFCore.utils import getToolByName

catalog = getToolByName(context, 'portal_catalog')
results = catalog.searchResults(portal_type='Google Video',
                                review_state='published',
                                sort_on='effective',
                                sort_order='reverse',
                                sort_limit=1)[:1]
if results:
    return results[0]



# This Python file uses the following encoding: utf-8

"""
$Id: testScripts.py 124560 2010-08-30 14:43:48Z thiromi $
"""

__author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
__docformat__ = 'restructuredtext'
__copyright__ = 'Copyright (C) 2007  DEMOS, Desarrollo de Medios, S.A. de C.V.'
__license__  = 'The GNU General Public License version 2 or later'

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# Import the base test case classes
from base import ATGoogleVideoTestCase

from Products.ATGoogleVideo.config import *

class TestGetLatestVideo(ATGoogleVideoTestCase):
    """Ensure latest video is obtained"""

    def afterSetUp(self):
        self.folder.invokeFactory('Google Video', 'video1')
        self.video1 = getattr(self.folder, 'video1')
        self.video1.setTitle('A title')
        self.video1.setDescription('A description')
        self.video1.setDocId('7111080333836653411')
        self.video1.setQuality('best')
        self.video1.setAutoPlay(False)
        self.video1.setTranscription('<p>video\'s transcription</p>')
        self.video1.setDimensions('300:150')

    def testIfVideoUnpublishedResultIsEmpty(self):
        self.failUnless(self.folder.getLatestGoogleVideo() is None)

    def testIfVideoPublishedResultIsNotEmpty(self):
        self.setRoles(['Manager', 'Member'])
        self.video1.content_status_modify(workflow_action='publish')
        self.failUnless(self.folder.getLatestGoogleVideo() is not None)

    def _testLatestVideoBrain(self):
        """this is not working because attributes are not indexed correctly"""
        self.setRoles(['Manager', 'Member'])
        self.video1.content_status_modify(workflow_action='publish')
        latest_video = self.folder.getLatestGoogleVideo()
        self.assertEqual(latest_video.Title, 'A title')
        self.assertEqual(latest_video.Description, 'A description')
        self.assertEqual(latest_video.docId, '7111080333836653411')
        self.assertEqual(latest_video.quality, 'best')
        self.assertEqual(latest_video.autoPlay, False)
        self.assertEqual(latest_video.getTranscription(), '<p>video\'s transcription</p>')
        self.assertEqual(latest_video.getWidth(), '300')
        self.assertEqual(latest_video.getHeight(), '150')


GOOGLE_VIDEO_BASE_CODE = """
    /* <![CDATA[ */
    var FO = { movie:'http://video.google.com/googleplayer.swf?docId=%s', width:'%s', height:'%s', majorversion:'9', build:'28', flashvars:'%s', quality:'%s', wmode:'transparent', setcontainercss:'true' };
    UFO.create(FO, 'video');
    /* ]]> */
"""

YOUTUBE_BASE_CODE = """
    /* <![CDATA[ */
    var FO = { movie:'http://www.youtube.com/v/%s%s', width:'%s', height:'%s', majorversion:'9', build:'28', flashvars:'', quality:'%s', wmode:'transparent', setcontainercss:'true' };
    UFO.create(FO, 'video');
    /* ]]> */
"""

class TestUFOJSCode(ATGoogleVideoTestCase):
    """Ensure Javascript code for UFO is generated"""

    def afterSetUp(self):
        self.folder.invokeFactory('Google Video', 'video1')
        self.video1 = getattr(self.folder, 'video1')
        self.video1.setTitle('A title')
        self.video1.setDescription('A description')
        self.video1.setQuality('best')
        self.video1.setAutoPlay(False)
        self.video1.setTranscription('<p>video\'s transcription</p>')
        self.video1.setDimensions('300:150')

    def testUFOForGoogleVideo(self):
        self.video1.setDocId('7111080333836653411')
        code = GOOGLE_VIDEO_BASE_CODE % ('7111080333836653411', '300', '150', '', 'best')
        ufo_code = self.folder.getUFOJSCodeFromVideo(self.video1.getDocId(), self.video1.getQuality(), self.video1.getAutoPlay(), width=self.video1.getWidth(), height=self.video1.getHeight())
        self.assertEqual(code, ufo_code)

        self.video1.setQuality('low')
        self.video1.setAutoPlay(True)
        code = GOOGLE_VIDEO_BASE_CODE % ('7111080333836653411', '300', '150', 'autoplay=true', 'low')
        ufo_code = self.folder.getUFOJSCodeFromVideo(self.video1.getDocId(), self.video1.getQuality(), self.video1.getAutoPlay(), width=self.video1.getWidth(), height=self.video1.getHeight())
        self.assertEqual(code, ufo_code)

    def testUFOForYouTube(self):
        self.video1.setDocId('nojWJ6-XmeQ')
        code = YOUTUBE_BASE_CODE % ('nojWJ6-XmeQ', '', '300', '150', 'best')
        ufo_code = self.folder.getUFOJSCodeFromVideo(self.video1.getDocId(), self.video1.getQuality(), self.video1.getAutoPlay(), width=self.video1.getWidth(), height=self.video1.getHeight())
        self.assertEqual(code, ufo_code)

        self.video1.setQuality('low')
        self.video1.setAutoPlay(True)
        code = YOUTUBE_BASE_CODE % ('nojWJ6-XmeQ', '&amp;autoplay=1', '300', '150', 'low')
        ufo_code = self.folder.getUFOJSCodeFromVideo(self.video1.getDocId(), self.video1.getQuality(), self.video1.getAutoPlay(), width=self.video1.getWidth(), height=self.video1.getHeight())
        self.assertEqual(code, ufo_code)

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestGetLatestVideo))
    suite.addTest(makeSuite(TestUFOJSCode))
    return suite

if __name__ == '__main__':
    framework()
